==> dialog-1.0.5-sources.jar: cn/lsmya/dialog/BottomWidthDialogById.java <==
package cn.lsmya.dialog;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Gravity;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.TextView;

import androidx.annotation.NonNull;

/**
 * 底部弹出dialog，宽度等于屏幕宽度
 * 实例化时传入布局id
 */
public class BottomWidthDialogById extends Dialog {

    private Context context;
    private int layoutResID;

    public BottomWidthDialogById(@NonNull Context context, int layoutResID) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.layoutResID = layoutResID;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Window window = getWindow();
        window.setGravity(Gravity.BOTTOM);
        window.setWindowAnimations(R.style.kit_bottom_menu_animation);
        setContentView(layoutResID);
        WindowManager manager = ((Activity) context).getWindowManager();
        DisplayMetrics outMetrics = new DisplayMetrics();
        manager.getDefaultDisplay().getMetrics(outMetrics);
        WindowManager.LayoutParams lp = getWindow().getAttributes();
        lp.width = outMetrics.widthPixels;
        getWindow().setAttributes(lp);
        setCanceledOnTouchOutside(true);
    }

    public <T extends View> T getView(int id) {
        return findViewById(id);
    }

    @Override
    public void dismiss() {
        View view = getCurrentFocus();
        if (view instanceof TextView) {
            InputMethodManager mInputMethodManager = (InputMethodManager) getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
            mInputMethodManager.hideSoftInputFromWindow(view.getWindowToken(), InputMethodManager.RESULT_UNCHANGED_SHOWN);
        }
        super.dismiss();
    }
}

==> dialog-1.0.8-sources.jar: cn/lsmya/dialog/BottomWidthDialogById.java <==
package cn.lsmya.dialog;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Gravity;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.TextView;

import androidx.annotation.NonNull;

/**
 * 底部弹出dialog，宽度等于屏幕宽度
 * 实例化时传入布局id
 */
public class BottomWidthDialogById extends Dialog {

    private Context context;
    private int layoutResID;

    public BottomWidthDialogById(@NonNull Context context, int layoutResID) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.layoutResID = layoutResID;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Window window = getWindow();
        window.setGravity(Gravity.BOTTOM);
        window.setWindowAnimations(R.style.helper_dialog_bottom_menu_animation);
        setContentView(layoutResID);
        WindowManager manager = ((Activity) context).getWindowManager();
        DisplayMetrics outMetrics = new DisplayMetrics();
        manager.getDefaultDisplay().getMetrics(outMetrics);
        WindowManager.LayoutParams lp = getWindow().getAttributes();
        lp.width = outMetrics.widthPixels;
        getWindow().setAttributes(lp);
        setCanceledOnTouchOutside(true);
    }

    public <T extends View> T getView(int id) {
        return findViewById(id);
    }

    @Override
    public void dismiss() {
        View view = getCurrentFocus();
        if (view instanceof TextView) {
            InputMethodManager mInputMethodManager = (InputMethodManager) getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
            mInputMethodManager.hideSoftInputFromWindow(view.getWindowToken(), InputMethodManager.RESULT_UNCHANGED_SHOWN);
        }
        super.dismiss();
    }
}
